@@ -4,7 +4,7 @@
 
 import _encoder
 
-def _swig_setattr(self,class_type,name,value):
+def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
             self.__dict__[name] = value.this
@@ -13,7 +13,13 @@ def _swig_setattr(self,class_type,name,value):
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    self.__dict__[name] = value
+    if (not static) or hasattr(self,name) or (name == "thisown"):
+        self.__dict__[name] = value
+    else:
+        raise AttributeError("You cannot add attributes to %s" % self)
+
+def _swig_setattr(self,class_type,name,value):
+    return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
     method = class_type.__swig_getmethods__.get(name,None)
@@ -45,7 +51,7 @@ class FileDecoder(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, FileDecoder, name)
     def __repr__(self):
-        return "<C FLAC__FileDecoder instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__FileDecoder instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["protected_"] = _encoder.FileDecoder_protected__set
     __swig_getmethods__["protected_"] = _encoder.FileDecoder_protected__get
     if _newclass:protected_ = property(_encoder.FileDecoder_protected__get, _encoder.FileDecoder_protected__set)
@@ -60,6 +66,7 @@ class FileDecoder(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class FileDecoderPtr(FileDecoder):
     def __init__(self, this):
         _swig_setattr(self, FileDecoder, 'this', this)
@@ -81,7 +88,7 @@ class FileEncoder(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, FileEncoder, name)
     def __repr__(self):
-        return "<C FLAC__FileEncoder instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__FileEncoder instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["protected_"] = _encoder.FileEncoder_protected__set
     __swig_getmethods__["protected_"] = _encoder.FileEncoder_protected__get
     if _newclass:protected_ = property(_encoder.FileEncoder_protected__get, _encoder.FileEncoder_protected__set)
@@ -142,6 +149,7 @@ class FileEncoder(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class FileEncoderPtr(FileEncoder):
     def __init__(self, this):
         _swig_setattr(self, FileEncoder, 'this', this)
@@ -155,7 +163,7 @@ class Metadata(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Metadata, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["type"] = _encoder.Metadata_type_set
     __swig_getmethods__["type"] = _encoder.Metadata_type_get
     if _newclass:type = property(_encoder.Metadata_type_get, _encoder.Metadata_type_set)
@@ -175,6 +183,7 @@ class Metadata(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class MetadataPtr(Metadata):
     def __init__(self, this):
         _swig_setattr(self, Metadata, 'this', this)
@@ -188,7 +197,7 @@ class FLAC__StreamMetadata_data(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, FLAC__StreamMetadata_data, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_data instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_data instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["stream_info"] = _encoder.FLAC__StreamMetadata_data_stream_info_set
     __swig_getmethods__["stream_info"] = _encoder.FLAC__StreamMetadata_data_stream_info_get
     if _newclass:stream_info = property(_encoder.FLAC__StreamMetadata_data_stream_info_get, _encoder.FLAC__StreamMetadata_data_stream_info_set)
@@ -218,6 +227,7 @@ class FLAC__StreamMetadata_data(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class FLAC__StreamMetadata_dataPtr(FLAC__StreamMetadata_data):
     def __init__(self, this):
         _swig_setattr(self, FLAC__StreamMetadata_data, 'this', this)
@@ -231,7 +241,7 @@ class StreamInfo(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, StreamInfo, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_StreamInfo instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_StreamInfo instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["min_blocksize"] = _encoder.StreamInfo_min_blocksize_set
     __swig_getmethods__["min_blocksize"] = _encoder.StreamInfo_min_blocksize_get
     if _newclass:min_blocksize = property(_encoder.StreamInfo_min_blocksize_get, _encoder.StreamInfo_min_blocksize_set)
@@ -267,6 +277,7 @@ class StreamInfo(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class StreamInfoPtr(StreamInfo):
     def __init__(self, this):
         _swig_setattr(self, StreamInfo, 'this', this)
@@ -280,7 +291,7 @@ class Padding(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Padding, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_Padding instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_Padding instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["dummy"] = _encoder.Padding_dummy_set
     __swig_getmethods__["dummy"] = _encoder.Padding_dummy_get
     if _newclass:dummy = property(_encoder.Padding_dummy_get, _encoder.Padding_dummy_set)
@@ -292,6 +303,7 @@ class Padding(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class PaddingPtr(Padding):
     def __init__(self, this):
         _swig_setattr(self, Padding, 'this', this)
@@ -305,7 +317,7 @@ class Application(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Application, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_Application instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_Application instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["id"] = _encoder.Application_id_set
     __swig_getmethods__["id"] = _encoder.Application_id_get
     if _newclass:id = property(_encoder.Application_id_get, _encoder.Application_id_set)
@@ -320,6 +332,7 @@ class Application(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class ApplicationPtr(Application):
     def __init__(self, this):
         _swig_setattr(self, Application, 'this', this)
@@ -333,7 +346,7 @@ class SeekPoint(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, SeekPoint, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_SeekPoint instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_SeekPoint instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["sample_number"] = _encoder.SeekPoint_sample_number_set
     __swig_getmethods__["sample_number"] = _encoder.SeekPoint_sample_number_get
     if _newclass:sample_number = property(_encoder.SeekPoint_sample_number_get, _encoder.SeekPoint_sample_number_set)
@@ -351,6 +364,7 @@ class SeekPoint(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class SeekPointPtr(SeekPoint):
     def __init__(self, this):
         _swig_setattr(self, SeekPoint, 'this', this)
@@ -364,7 +378,7 @@ class SeekTable(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, SeekTable, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_SeekTable instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_SeekTable instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["num_points"] = _encoder.SeekTable_num_points_set
     __swig_getmethods__["num_points"] = _encoder.SeekTable_num_points_get
     if _newclass:num_points = property(_encoder.SeekTable_num_points_get, _encoder.SeekTable_num_points_set)
@@ -379,6 +393,7 @@ class SeekTable(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class SeekTablePtr(SeekTable):
     def __init__(self, this):
         _swig_setattr(self, SeekTable, 'this', this)
@@ -392,7 +407,7 @@ class VorbisCommentEntry(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, VorbisCommentEntry, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_VorbisComment_Entry instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_VorbisComment_Entry instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["length"] = _encoder.VorbisCommentEntry_length_set
     __swig_getmethods__["length"] = _encoder.VorbisCommentEntry_length_get
     if _newclass:length = property(_encoder.VorbisCommentEntry_length_get, _encoder.VorbisCommentEntry_length_set)
@@ -407,6 +422,7 @@ class VorbisCommentEntry(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class VorbisCommentEntryPtr(VorbisCommentEntry):
     def __init__(self, this):
         _swig_setattr(self, VorbisCommentEntry, 'this', this)
@@ -420,7 +436,7 @@ class VorbisComment(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, VorbisComment, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_VorbisComment instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_VorbisComment instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["vendor_string"] = _encoder.VorbisComment_vendor_string_set
     __swig_getmethods__["vendor_string"] = _encoder.VorbisComment_vendor_string_get
     if _newclass:vendor_string = property(_encoder.VorbisComment_vendor_string_get, _encoder.VorbisComment_vendor_string_set)
@@ -438,6 +454,7 @@ class VorbisComment(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class VorbisCommentPtr(VorbisComment):
     def __init__(self, this):
         _swig_setattr(self, VorbisComment, 'this', this)
@@ -451,7 +468,7 @@ class CueSheetIndex(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, CueSheetIndex, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_CueSheet_Index instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_CueSheet_Index instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["offset"] = _encoder.CueSheetIndex_offset_set
     __swig_getmethods__["offset"] = _encoder.CueSheetIndex_offset_get
     if _newclass:offset = property(_encoder.CueSheetIndex_offset_get, _encoder.CueSheetIndex_offset_set)
@@ -466,6 +483,7 @@ class CueSheetIndex(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class CueSheetIndexPtr(CueSheetIndex):
     def __init__(self, this):
         _swig_setattr(self, CueSheetIndex, 'this', this)
@@ -479,7 +497,7 @@ class CueSheetTrack(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, CueSheetTrack, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_CueSheet_Track instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_CueSheet_Track instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["offset"] = _encoder.CueSheetTrack_offset_set
     __swig_getmethods__["offset"] = _encoder.CueSheetTrack_offset_get
     if _newclass:offset = property(_encoder.CueSheetTrack_offset_get, _encoder.CueSheetTrack_offset_set)
@@ -509,6 +527,7 @@ class CueSheetTrack(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class CueSheetTrackPtr(CueSheetTrack):
     def __init__(self, this):
         _swig_setattr(self, CueSheetTrack, 'this', this)
@@ -522,7 +541,7 @@ class CueSheet(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, CueSheet, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_CueSheet instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_CueSheet instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["media_catalog_number"] = _encoder.CueSheet_media_catalog_number_set
     __swig_getmethods__["media_catalog_number"] = _encoder.CueSheet_media_catalog_number_get
     if _newclass:media_catalog_number = property(_encoder.CueSheet_media_catalog_number_get, _encoder.CueSheet_media_catalog_number_set)
@@ -546,6 +565,7 @@ class CueSheet(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class CueSheetPtr(CueSheet):
     def __init__(self, this):
         _swig_setattr(self, CueSheet, 'this', this)
@@ -559,7 +579,7 @@ class Unknown(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Unknown, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_Unknown instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_Unknown instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["data"] = _encoder.Unknown_data_set
     __swig_getmethods__["data"] = _encoder.Unknown_data_get
     if _newclass:data = property(_encoder.Unknown_data_get, _encoder.Unknown_data_set)
@@ -571,6 +591,7 @@ class Unknown(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class UnknownPtr(Unknown):
     def __init__(self, this):
         _swig_setattr(self, Unknown, 'this', this)
