@@ -4,7 +4,7 @@
 
 import _sw_metadata
 
-def _swig_setattr(self,class_type,name,value):
+def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
             self.__dict__[name] = value.this
@@ -13,7 +13,13 @@ def _swig_setattr(self,class_type,name,value):
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    self.__dict__[name] = value
+    if (not static) or hasattr(self,name) or (name == "thisown"):
+        self.__dict__[name] = value
+    else:
+        raise AttributeError("You cannot add attributes to %s" % self)
+
+def _swig_setattr(self,class_type,name,value):
+    return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
     method = class_type.__swig_getmethods__.get(name,None)
@@ -47,7 +53,7 @@ class FileDecoder(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, FileDecoder, name)
     def __repr__(self):
-        return "<C FLAC__FileDecoder instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__FileDecoder instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["protected_"] = _sw_metadata.FileDecoder_protected__set
     __swig_getmethods__["protected_"] = _sw_metadata.FileDecoder_protected__get
     if _newclass:protected_ = property(_sw_metadata.FileDecoder_protected__get, _sw_metadata.FileDecoder_protected__set)
@@ -62,6 +68,7 @@ class FileDecoder(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class FileDecoderPtr(FileDecoder):
     def __init__(self, this):
         _swig_setattr(self, FileDecoder, 'this', this)
@@ -83,7 +90,7 @@ class FileEncoder(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, FileEncoder, name)
     def __repr__(self):
-        return "<C FLAC__FileEncoder instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__FileEncoder instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["protected_"] = _sw_metadata.FileEncoder_protected__set
     __swig_getmethods__["protected_"] = _sw_metadata.FileEncoder_protected__get
     if _newclass:protected_ = property(_sw_metadata.FileEncoder_protected__get, _sw_metadata.FileEncoder_protected__set)
@@ -98,6 +105,7 @@ class FileEncoder(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class FileEncoderPtr(FileEncoder):
     def __init__(self, this):
         _swig_setattr(self, FileEncoder, 'this', this)
@@ -111,7 +119,7 @@ class Metadata(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Metadata, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["type"] = _sw_metadata.Metadata_type_set
     __swig_getmethods__["type"] = _sw_metadata.Metadata_type_get
     if _newclass:type = property(_sw_metadata.Metadata_type_get, _sw_metadata.Metadata_type_set)
@@ -130,6 +138,7 @@ class Metadata(_object):
         try:
             if self.thisown: destroy(self)
         except: pass
+
     def clone(*args): return _sw_metadata.Metadata_clone(*args)
     def is_equal(*args): return _sw_metadata.Metadata_is_equal(*args)
     def application_set_data(*args): return _sw_metadata.Metadata_application_set_data(*args)
@@ -174,7 +183,7 @@ class FLAC__StreamMetadata_data(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, FLAC__StreamMetadata_data, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_data instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_data instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["stream_info"] = _sw_metadata.FLAC__StreamMetadata_data_stream_info_set
     __swig_getmethods__["stream_info"] = _sw_metadata.FLAC__StreamMetadata_data_stream_info_get
     if _newclass:stream_info = property(_sw_metadata.FLAC__StreamMetadata_data_stream_info_get, _sw_metadata.FLAC__StreamMetadata_data_stream_info_set)
@@ -204,6 +213,7 @@ class FLAC__StreamMetadata_data(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class FLAC__StreamMetadata_dataPtr(FLAC__StreamMetadata_data):
     def __init__(self, this):
         _swig_setattr(self, FLAC__StreamMetadata_data, 'this', this)
@@ -217,7 +227,7 @@ class StreamInfo(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, StreamInfo, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_StreamInfo instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_StreamInfo instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["min_blocksize"] = _sw_metadata.StreamInfo_min_blocksize_set
     __swig_getmethods__["min_blocksize"] = _sw_metadata.StreamInfo_min_blocksize_get
     if _newclass:min_blocksize = property(_sw_metadata.StreamInfo_min_blocksize_get, _sw_metadata.StreamInfo_min_blocksize_set)
@@ -253,6 +263,7 @@ class StreamInfo(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class StreamInfoPtr(StreamInfo):
     def __init__(self, this):
         _swig_setattr(self, StreamInfo, 'this', this)
@@ -266,7 +277,7 @@ class Padding(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Padding, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_Padding instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_Padding instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["dummy"] = _sw_metadata.Padding_dummy_set
     __swig_getmethods__["dummy"] = _sw_metadata.Padding_dummy_get
     if _newclass:dummy = property(_sw_metadata.Padding_dummy_get, _sw_metadata.Padding_dummy_set)
@@ -278,6 +289,7 @@ class Padding(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class PaddingPtr(Padding):
     def __init__(self, this):
         _swig_setattr(self, Padding, 'this', this)
@@ -291,7 +303,7 @@ class Application(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Application, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_Application instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_Application instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["id"] = _sw_metadata.Application_id_set
     __swig_getmethods__["id"] = _sw_metadata.Application_id_get
     if _newclass:id = property(_sw_metadata.Application_id_get, _sw_metadata.Application_id_set)
@@ -306,6 +318,7 @@ class Application(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class ApplicationPtr(Application):
     def __init__(self, this):
         _swig_setattr(self, Application, 'this', this)
@@ -319,7 +332,7 @@ class SeekPoint(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, SeekPoint, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_SeekPoint instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_SeekPoint instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["sample_number"] = _sw_metadata.SeekPoint_sample_number_set
     __swig_getmethods__["sample_number"] = _sw_metadata.SeekPoint_sample_number_get
     if _newclass:sample_number = property(_sw_metadata.SeekPoint_sample_number_get, _sw_metadata.SeekPoint_sample_number_set)
@@ -338,6 +351,7 @@ class SeekPoint(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class SeekPointPtr(SeekPoint):
     def __init__(self, this):
         _swig_setattr(self, SeekPoint, 'this', this)
@@ -351,7 +365,7 @@ class SeekTable(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, SeekTable, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_SeekTable instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_SeekTable instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["num_points"] = _sw_metadata.SeekTable_num_points_set
     __swig_getmethods__["num_points"] = _sw_metadata.SeekTable_num_points_get
     if _newclass:num_points = property(_sw_metadata.SeekTable_num_points_get, _sw_metadata.SeekTable_num_points_set)
@@ -366,6 +380,7 @@ class SeekTable(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class SeekTablePtr(SeekTable):
     def __init__(self, this):
         _swig_setattr(self, SeekTable, 'this', this)
@@ -379,7 +394,7 @@ class VorbisCommentEntry(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, VorbisCommentEntry, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_VorbisComment_Entry instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_VorbisComment_Entry instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["length"] = _sw_metadata.VorbisCommentEntry_length_set
     __swig_getmethods__["length"] = _sw_metadata.VorbisCommentEntry_length_get
     if _newclass:length = property(_sw_metadata.VorbisCommentEntry_length_get, _sw_metadata.VorbisCommentEntry_length_set)
@@ -396,6 +411,7 @@ class VorbisCommentEntry(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class VorbisCommentEntryPtr(VorbisCommentEntry):
     def __init__(self, this):
         _swig_setattr(self, VorbisCommentEntry, 'this', this)
@@ -409,7 +425,7 @@ class VorbisComment(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, VorbisComment, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_VorbisComment instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_VorbisComment instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["vendor_string"] = _sw_metadata.VorbisComment_vendor_string_set
     __swig_getmethods__["vendor_string"] = _sw_metadata.VorbisComment_vendor_string_get
     if _newclass:vendor_string = property(_sw_metadata.VorbisComment_vendor_string_get, _sw_metadata.VorbisComment_vendor_string_set)
@@ -427,6 +443,7 @@ class VorbisComment(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class VorbisCommentPtr(VorbisComment):
     def __init__(self, this):
         _swig_setattr(self, VorbisComment, 'this', this)
@@ -440,7 +457,7 @@ class CueSheetIndex(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, CueSheetIndex, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_CueSheet_Index instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_CueSheet_Index instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["offset"] = _sw_metadata.CueSheetIndex_offset_set
     __swig_getmethods__["offset"] = _sw_metadata.CueSheetIndex_offset_get
     if _newclass:offset = property(_sw_metadata.CueSheetIndex_offset_get, _sw_metadata.CueSheetIndex_offset_set)
@@ -456,6 +473,7 @@ class CueSheetIndex(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class CueSheetIndexPtr(CueSheetIndex):
     def __init__(self, this):
         _swig_setattr(self, CueSheetIndex, 'this', this)
@@ -469,7 +487,7 @@ class CueSheetTrack(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, CueSheetTrack, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_CueSheet_Track instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_CueSheet_Track instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["offset"] = _sw_metadata.CueSheetTrack_offset_set
     __swig_getmethods__["offset"] = _sw_metadata.CueSheetTrack_offset_get
     if _newclass:offset = property(_sw_metadata.CueSheetTrack_offset_get, _sw_metadata.CueSheetTrack_offset_set)
@@ -498,6 +516,7 @@ class CueSheetTrack(_object):
         try:
             if self.thisown: destroy(self)
         except: pass
+
     def clone(*args): return _sw_metadata.CueSheetTrack_clone(*args)
     def __getitem__(*args): return _sw_metadata.CueSheetTrack___getitem__(*args)
 
@@ -514,7 +533,7 @@ class CueSheet(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, CueSheet, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_CueSheet instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_CueSheet instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["media_catalog_number"] = _sw_metadata.CueSheet_media_catalog_number_set
     __swig_getmethods__["media_catalog_number"] = _sw_metadata.CueSheet_media_catalog_number_get
     if _newclass:media_catalog_number = property(_sw_metadata.CueSheet_media_catalog_number_get, _sw_metadata.CueSheet_media_catalog_number_set)
@@ -538,6 +557,7 @@ class CueSheet(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class CueSheetPtr(CueSheet):
     def __init__(self, this):
         _swig_setattr(self, CueSheet, 'this', this)
@@ -551,7 +571,7 @@ class Unknown(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Unknown, name)
     def __repr__(self):
-        return "<C FLAC__StreamMetadata_Unknown instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__StreamMetadata_Unknown instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     __swig_setmethods__["data"] = _sw_metadata.Unknown_data_set
     __swig_getmethods__["data"] = _sw_metadata.Unknown_data_get
     if _newclass:data = property(_sw_metadata.Unknown_data_get, _sw_metadata.Unknown_data_set)
@@ -563,6 +583,7 @@ class Unknown(_object):
             if self.thisown: destroy(self)
         except: pass
 
+
 class UnknownPtr(Unknown):
     def __init__(self, this):
         _swig_setattr(self, Unknown, 'this', this)
@@ -596,7 +617,7 @@ class Chain(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Chain, name)
     def __repr__(self):
-        return "<C FLAC__Metadata_Chain instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__Metadata_Chain instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
         _swig_setattr(self, Chain, 'this', _sw_metadata.new_Chain(*args))
         _swig_setattr(self, Chain, 'thisown', 1)
@@ -604,6 +625,7 @@ class Chain(_object):
         try:
             if self.thisown: destroy(self)
         except: pass
+
     def status(*args): return _sw_metadata.Chain_status(*args)
     def read(*args): return _sw_metadata.Chain_read(*args)
     def write(*args): return _sw_metadata.Chain_write(*args)
@@ -623,7 +645,7 @@ class Iterator(_object):
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, Iterator, name)
     def __repr__(self):
-        return "<C FLAC__Metadata_Iterator instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C FLAC__Metadata_Iterator instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
         _swig_setattr(self, Iterator, 'this', _sw_metadata.new_Iterator(*args))
         _swig_setattr(self, Iterator, 'thisown', 1)
@@ -631,6 +653,7 @@ class Iterator(_object):
         try:
             if self.thisown: destroy(self)
         except: pass
+
     def init(*args): return _sw_metadata.Iterator_init(*args)
     def next(*args): return _sw_metadata.Iterator_next(*args)
     def prev(*args): return _sw_metadata.Iterator_prev(*args)
